@@ -1,4 +1,8 @@
 #!/usr/bin/env perl
+use 5.006;
+use strict;
+use warnings;
+
 # t/32_same_arity.pl: invoked by t/32_same_arity.t
 {
     package main::oops;
